import React, { useMemo, useRef, useState, useEffect } from 'react'
import { Link } from 'react-router-dom'
import {useGoogleAuth} from 'hooks'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faUser } from '@fortawesome/free-solid-svg-icons'
import { AccountPage } from 'pages'
import { Box, Heading, Flex, Spacer, Button, Image, Avatar, HStack, Input } from "@chakra-ui/react"
import AppLogo from '../img/logo.png'
import NisumLogo from '../img/nisum.jpeg'
import {
    Drawer,
    DrawerBody,
    DrawerHeader,
    DrawerOverlay,
    DrawerContent,
    DrawerCloseButton,
    useDisclosure
  } from "@chakra-ui/react"

  import {
    Menu,
    MenuButton,
    MenuList,
    MenuItem,
    MenuItemOption,
    MenuGroup,
    MenuOptionGroup,
    MenuIcon,
    MenuCommand,
    MenuDivider,
  } from "@chakra-ui/react"

  import { ChevronDownIcon } from '@chakra-ui/icons'


const Nav = () => {
    const { isSignedIn, signOut, signIn, manager } = useGoogleAuth();
    const handleAuth = () => { isSignedIn ? signOut() : signIn();}
    const loginIcon = faUser
    const authLinkText = useMemo(() => isSignedIn ? "Logout" : "Login", [isSignedIn]);
    const { isOpen, onOpen, onClose } = useDisclosure();
    const btnRef = useRef<HTMLButtonElement>(null);
    const userName = isSignedIn ? <p>{manager.firstName} {manager.lastName}</p> : null
    const userIcon = isSignedIn ? 
    <Avatar boxSize="40px" borderRadius="full"  src={manager.imageUrl} alt="profile"/> : <div>{authLinkText}</div>




    return (
        <Flex className="header" justifyContent="space-between">
            <Box >
                <Image 
                    mt="-4px"
                    src={NisumLogo} 
                    alt="Nisum - Celebrating 20+ years logo"
                    height="45px"
                    // width="950px"
                />
            </Box>
            <Box className="center-nav" display="-ms-inline-flexbox">
                <HStack>
                    <Link to="/"><Image src={AppLogo} alt="Order Management Console PRO logo" className="logoImg"/></Link>
                   
                    <h1>Order Management</h1>
                    {/* <Link to="/"><h1>Order Management</h1></Link> */}
                </HStack>
            </Box>
            {/* <HStack className="right-nav" spacing="1px">
                <Box><button onClick={handleAuth}>{authLinkText}</button></Box>
                <Box><button ref={btnRef} onClick={onOpen}>{userIcon}</button></Box>
                <Drawer
                    isOpen={isOpen}
                    placement="right"
                    onClose={onClose}
                    finalFocusRef={btnRef}
                    >
                    <DrawerOverlay />
                    <DrawerContent>
                        <DrawerCloseButton size="sm"/>
                        <DrawerHeader align="center" >User Account</DrawerHeader>
                        <DrawerBody>
                            <AccountPage />
                        </DrawerBody>
                    </DrawerContent>
                </Drawer>
            </HStack> */}
            <Box >
                <Menu>
                    <MenuButton rightIcon={<ChevronDownIcon />} onClick={onOpen} width="300px" className="right-nav">
                        <HStack>
                            <span>{userIcon}</span> 
                            <span>{userName}</span>
                            {/* <span>{authLinkText}</span> */}
                        </HStack>
                    </MenuButton>
                    <MenuList>
                        <MenuItem color="black"><Link to="/orders">Orders</Link></MenuItem>
                        <MenuItem color="black"><Link to="/account">Account</Link></MenuItem>
                        <MenuItem color="black"><button onClick={handleAuth}>{authLinkText}</button></MenuItem>
                    </MenuList>
                </Menu>
            </Box>
        </Flex>
    )
}

export default Nav
